/*
 * Written by Ed Hong UWT Feb. 19, 2003.
 * Modified by Donald Chinn May 14, 2003.
 */

/**
 * Class that represents an edge in a graph.
 * An object (usually some sort of data) can be associated with the edge.
 * 
 * A label (also represented by an object (e.g., a string) can also be
 * associated with an edge.  This could be useful, for example, if you
 * need to mark an edge as being visited in some graph traversal.
 * 
 * @author edhong
 * @version 0.0
 */
public class Edge {
    /** the first endpoint of the edge */
    Vertex v1;
    
    /** the second endpoint of the edge */
    Vertex v2;
    
    private Object elementdat;  // an object associated with this edge
    private Object visitLabel;  // a label associated with this edge
    
    /**
     * Constructor that allows an object to be associated
     * with the edge.
     * @param v     the first endpoint of this edge
     * @param w     the second endpoint of this edge
     * @param o     an object to be associated with this edge
     */
    public Edge (Vertex v, Vertex w, Object o) {
        this.elementdat = o;
        this.v1 = v;
        this.v2 = w;
    }
    
    /**
     * Return the object associated with this edge.
     * @return  the object of this edge
     */
    public Object element(){
        return this.elementdat;
    }
    
    /**
     * Return the label associated with this edge.
     * @return  the label of this edge
     */
    public Object getLabel() {
        return visitLabel;
    }
        
    /**
     * Set the label associated with this edge.
     * @param o  the label of this edge
     */
    public void setLabel(Object o) {
        visitLabel = o;
    }
}
